@@ -10,6 +10,14 @@ class APIError(Exception):
     pass
 
 
+class HTTPBadRequestError(APIError):
+    pass
+
+
+class AuthError(HandledError):
+    pass
+
+
 class APITimeoutError(HandledError):
     pass
 
@@ -52,6 +60,7 @@ class TlmNotCalibratedError(HandledError):
 # HTTP status codes
 HTTP_OK = 200
 HTTP_BAD_REQUEST = 400
+HTTP_UNAUTHORIZED = 401
 HTTP_UNPROCESSABLE_ENTITY = 422
 HTTP_TOO_MANY_REQUESTS = 429
 HTTP_SERVICE_UNAVAILABLE = 503
