@@ -14,7 +14,6 @@ from cleanlab_tlm.internal.constants import (
     _TLM_MAX_TOKEN_RANGE,
     _VALID_TLM_MODELS,
     _VALID_TLM_TASKS,
-    TLM_MODELS_NOT_SUPPORTING_EXPLANATION,
     TLM_NUM_SELF_REFLECTIONS_RANGE,
     TLM_REASONING_EFFORT_VALUES,
     TLM_SIMILARITY_MEASURES,
@@ -93,9 +92,7 @@ def _get_options_dictionary(model: Optional[str]) -> TLMOptions:
     add_num_self_reflections = np.random.choice([True, False])
     add_similarity_measure = np.random.choice([True, False])
     add_reasoning_effort = np.random.choice([True, False])
-    add_log_explanation = (
-        np.random.choice([True, False]) if model not in TLM_MODELS_NOT_SUPPORTING_EXPLANATION else False
-    )
+    add_log_explanation = np.random.choice([True, False])
     add_log_perplexity_score = np.random.choice([True, False])
 
     options: dict[str, Any] = {}
